==> haskell-monad-control-1.0.2.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.2
id: monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
key: monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Trans.Control
abi: ce72e9c06e97f7bac790a30fd0148a82
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-control-1.0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-control-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-control-1.0.2.2
hs-libraries: HSmonad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
depends:
    base-4.10.1.0 stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
    transformers-0.5.2.0 transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=0446e63134f05bfe811d0020407f145f
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.2
id: monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv
key: monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Trans.Control
abi: 4ed72a305de1efe6a7bffe480e981599
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-control-1.0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-control-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-control-1.0.2.2
hs-libraries: HSmonad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    transformers-0.5.2.0 transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
